@@ -1,11 +1,10 @@
 from django.contrib import admin
 from django.contrib.auth.admin import UserAdmin
-from django.contrib.auth.models import User
 from django.utils.translation import ugettext as _
 from guardian.admin import GuardedModelAdmin
 
 from userena.models import UserenaSignup
-from userena.utils import get_profile_model
+from userena.utils import get_profile_model, get_user_model
 
 class UserenaSignupInline(admin.StackedInline):
     model = UserenaSignup
@@ -14,8 +13,9 @@ class UserenaSignupInline(admin.StackedInline):
 class UserenaAdmin(UserAdmin, GuardedModelAdmin):
     inlines = [UserenaSignupInline, ]
     list_display = ('username', 'email', 'first_name', 'last_name',
-                    'is_staff', 'date_joined')
+                    'is_staff', 'is_active', 'date_joined')
+    list_filter = ('is_staff', 'is_superuser', 'is_active')
 
-admin.site.unregister(User)
-admin.site.register(User, UserenaAdmin)
+admin.site.unregister(get_user_model())
+admin.site.register(get_user_model(), UserenaAdmin)
 admin.site.register(get_profile_model())
