@@ -1,13 +1,16 @@
 from django.conf import settings
-from django.utils.hashcompat import sha_constructor
 from django.contrib.auth.models import SiteProfileNotAvailable
 from django.db.models import get_model
 
+try:
+    from hashlib import sha1 as sha_constructor, md5 as md5_constructor
+except ImportError:
+    from django.utils.hashcompat import sha_constructor, md5_constructor
+
 from userena import settings as userena_settings
 
 import urllib, random, datetime
 
-from django.utils.hashcompat import md5_constructor
 
 def get_gravatar(email, size=80, default='identicon'):
     """ Get's a Gravatar for a email address.
@@ -144,3 +147,16 @@ def get_datetime_now():
         return timezone.now() # pragma: no cover
     except ImportError: # pragma: no cover
         return datetime.datetime.now()
+
+# Django 1.5 compatibility utilities, providing support for custom User models.
+# Since get_user_model() causes a circular import if called when app models are
+# being loaded, the user_model_label should be used when possible, with calls
+# to get_user_model deferred to execution time
+
+user_model_label = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
+
+try:
+    from django.contrib.auth import get_user_model
+except ImportError:
+    from django.contrib.auth.models import User
+    get_user_model = lambda: User
