@@ -3,7 +3,6 @@ from django.shortcuts import redirect, get_object_or_404
 from django.contrib.auth import authenticate, login, logout, REDIRECT_FIELD_NAME
 from django.contrib.auth.forms import PasswordChangeForm
 from django.contrib.auth.decorators import login_required
-from django.contrib.auth.models import User
 from django.contrib.auth.views import logout as Signout
 from django.views.generic import TemplateView
 from django.template.context import RequestContext
@@ -11,14 +10,14 @@ from django.views.generic.list import ListView
 from django.conf import settings
 from django.contrib import messages
 from django.utils.translation import ugettext as _
-from django.http import HttpResponseForbidden, Http404
+from django.http import HttpResponseForbidden, Http404, HttpResponseRedirect
 
 from userena.forms import (SignupForm, SignupFormOnlyEmail, AuthenticationForm,
                            ChangeEmailForm, EditProfileForm)
 from userena.models import UserenaSignup
 from userena.decorators import secure_required
 from userena.backends import UserenaAuthenticationBackend
-from userena.utils import signin_redirect, get_profile_model
+from userena.utils import signin_redirect, get_profile_model, get_user_model
 from userena import signals as userena_signals
 from userena import settings as userena_settings
 
@@ -38,15 +37,15 @@ class ExtraContextTemplateView(TemplateView):
 
     # this view is used in POST requests, e.g. signup when the form is not valid
     post = TemplateView.get
-        
+
 class ProfileListView(ListView):
     """ Lists all profiles """
     context_object_name='profile_list'
     page=1
     paginate_by=50
-    template_name='userena/profile_list.html'
+    template_name=userena_settings.USERENA_PROFILE_LIST_TEMPLATE
     extra_context=None
-    
+
     def get_context_data(self, **kwargs):
         # Call the base implementation first to get a context
         context = super(ProfileListView, self).get_context_data(**kwargs)
@@ -54,24 +53,24 @@ class ProfileListView(ListView):
             page = int(self.request.GET.get('page', None))
         except (TypeError, ValueError):
             page = self.page
-    
+
         if userena_settings.USERENA_DISABLE_PROFILE_LIST \
            and not self.request.user.is_staff:
             raise Http404
-        
+
         if not self.extra_context: self.extra_context = dict()
-        
+
         context['page'] = page
         context['paginate_by'] = self.paginate_by
         context['extra_context'] = self.extra_context
-        
+
         return context
-    
+
     def get_queryset(self):
         profile_model = get_profile_model()
         queryset = profile_model.objects.get_visible_profiles(self.request.user)
-        return queryset      
-        
+        return queryset
+
 @secure_required
 def signup(request, signup_form=SignupForm,
            template_name='userena/signup_form.html', success_url=None,
@@ -93,7 +92,7 @@ def signup(request, signup_form=SignupForm,
 
     :param success_url:
         String containing the URI which should be redirected to after a
-        successfull signup. If not supplied will redirect to
+        successful signup. If not supplied will redirect to
         ``userena_signup_complete`` view.
 
     :param extra_context:
@@ -131,6 +130,12 @@ def signup(request, signup_form=SignupForm,
             # A new signed user should logout the old one.
             if request.user.is_authenticated():
                 logout(request)
+
+            if (userena_settings.USERENA_SIGNIN_AFTER_SIGNUP and
+                not userena_settings.USERENA_ACTIVATION_REQUIRED):
+                user = authenticate(identification=user.email, check_password=False)
+                login(request, user)
+
             return redirect(redirect_to)
 
     if not extra_context: extra_context = dict()
@@ -147,8 +152,8 @@ def activate(request, activation_key,
 
     The key is a SHA1 string. When the SHA1 is found with an
     :class:`UserenaSignup`, the :class:`User` of that account will be
-    activated.  After a successfull activation the view will redirect to
-    ``succes_url``.  If the SHA1 is not found, the user will be shown the
+    activated.  After a successful activation the view will redirect to
+    ``success_url``.  If the SHA1 is not found, the user will be shown the
     ``template_name`` template displaying a fail message.
 
     :param activation_key:
@@ -158,12 +163,12 @@ def activate(request, activation_key,
 
     :param template_name:
         String containing the template name that is used when the
-        ``activation_key`` is invalid and the activation failes. Defaults to
+        ``activation_key`` is invalid and the activation fails. Defaults to
         ``userena/activation_fail.html``.
 
     :param success_url:
         String containing the URL where the user should be redirected to after
-        a succesfull activation. Will replace ``%(username)s`` with string
+        a successful activation. Will replace ``%(username)s`` with string
         formatting if supplied. If ``success_url`` is left empty, will direct
         to ``userena_profile_detail`` view.
 
@@ -211,11 +216,11 @@ def email_confirm(request, confirmation_key,
 
     :param template_name:
         String containing the template name which should be rendered when
-        confirmation fails. When confirmation is succesfull, no template is
+        confirmation fails. When confirmation is successful, no template is
         needed because the user will be redirected to ``success_url``.
 
     :param success_url:
-        String containing the URL which is redirected to after a succesfull
+        String containing the URL which is redirected to after a successful
         confirmation.  Supplied argument must be able to be rendered by
         ``reverse`` function.
 
@@ -269,7 +274,7 @@ def direct_to_user_template(request, username, template_name,
         The currently :class:`User` that is viewed.
 
     """
-    user = get_object_or_404(User, username__iexact=username)
+    user = get_object_or_404(get_user_model(), username__iexact=username)
 
     if not extra_context: extra_context = dict()
     extra_context['viewed_user'] = user
@@ -287,7 +292,7 @@ def signin(request, auth_form=AuthenticationForm,
     Signs a user in by combining email/username with password. If the
     combination is correct and the user :func:`is_active` the
     :func:`redirect_signin_function` is called with the arguments
-    ``REDIRECT_FIELD_NAME`` and an instance of the :class:`User` whois is
+    ``REDIRECT_FIELD_NAME`` and an instance of the :class:`User` who is is
     trying the login. The returned value of the function will be the URL that
     is redirected to.
 
@@ -303,7 +308,7 @@ def signin(request, auth_form=AuthenticationForm,
 
     :param redirect_field_name:
         Form field name which contains the value for a redirect to the
-        successing page. Defaults to ``next`` and is set in
+        succeeding page. Defaults to ``next`` and is set in
         ``REDIRECT_FIELD_NAME`` setting.
 
     :param redirect_signin_function:
@@ -321,7 +326,7 @@ def signin(request, auth_form=AuthenticationForm,
         Form used for authentication supplied by ``auth_form``.
 
     """
-    form = auth_form
+    form = auth_form()
 
     if request.method == 'POST':
         form = auth_form(request.POST, request.FILES)
@@ -344,7 +349,7 @@ def signin(request, auth_form=AuthenticationForm,
                 # Whereto now?
                 redirect_to = redirect_signin_function(
                     request.REQUEST.get(redirect_field_name), user)
-                return redirect(redirect_to)
+                return HttpResponseRedirect(redirect_to)
             else:
                 return redirect(reverse('userena_disabled',
                                         kwargs={'username': user.username}))
@@ -358,7 +363,7 @@ def signin(request, auth_form=AuthenticationForm,
                                             extra_context=extra_context)(request)
 
 @secure_required
-def signout(request, next_page=userena_settings.USERENA_REDIRECT_ON_SIGNOUT, 
+def signout(request, next_page=userena_settings.USERENA_REDIRECT_ON_SIGNOUT,
             template_name='userena/signout.html', *args, **kwargs):
     """
     Signs out the user and adds a success message ``You have been signed
@@ -378,7 +383,7 @@ def signout(request, next_page=userena_settings.USERENA_REDIRECT_ON_SIGNOUT,
     return Signout(request, next_page, template_name, *args, **kwargs)
 
 @secure_required
-@permission_required_or_403('change_user', (User, 'username', 'username'))
+@permission_required_or_403('change_user', (get_user_model(), 'username', 'username'))
 def email_change(request, username, email_form=ChangeEmailForm,
                  template_name='userena/email_form.html', success_url=None,
                  extra_context=None):
@@ -397,8 +402,8 @@ def email_change(request, username, email_form=ChangeEmailForm,
         Defaults to ``userena/email_form.html``.
 
     :param success_url:
-        Named URL where the user will get redirected to when succesfully
-        changing their email address.  When not suplied will redirect to
+        Named URL where the user will get redirected to when successfully
+        changing their email address.  When not supplied will redirect to
         ``userena_email_complete`` URL.
 
     :param extra_context:
@@ -421,7 +426,7 @@ def email_change(request, username, email_form=ChangeEmailForm,
     permissions to alter the email address of others.
 
     """
-    user = get_object_or_404(User, username__iexact=username)
+    user = get_object_or_404(get_user_model(), username__iexact=username)
 
     form = email_form(user)
 
@@ -445,7 +450,7 @@ def email_change(request, username, email_form=ChangeEmailForm,
                                             extra_context=extra_context)(request)
 
 @secure_required
-@permission_required_or_403('change_user', (User, 'username', 'username'))
+@permission_required_or_403('change_user', (get_user_model(), 'username', 'username'))
 def password_change(request, username, template_name='userena/password_form.html',
                     pass_form=PasswordChangeForm, success_url=None, extra_context=None):
     """ Change password of user.
@@ -453,7 +458,7 @@ def password_change(request, username, template_name='userena/password_form.html
     This view is almost a mirror of the view supplied in
     :func:`contrib.auth.views.password_change`, with the minor change that in
     this view we also use the username to change the password. This was needed
-    to keep our URLs logical (and REST) accross the entire application. And
+    to keep our URLs logical (and REST) across the entire application. And
     that in a later stadium administrators can also change the users password
     through the web application itself.
 
@@ -475,7 +480,7 @@ def password_change(request, username, template_name='userena/password_form.html
         ``userena_password_complete`` URL.
 
     :param extra_context:
-        Dictionary of extra variables that are passed on the the template. The
+        Dictionary of extra variables that are passed on to the template. The
         ``form`` key is always used by the form supplied by ``pass_form``.
 
     **Context**
@@ -484,7 +489,7 @@ def password_change(request, username, template_name='userena/password_form.html
         Form used to change the password.
 
     """
-    user = get_object_or_404(User,
+    user = get_object_or_404(get_user_model(),
                              username__iexact=username)
 
     form = pass_form(user=user)
@@ -518,7 +523,7 @@ def profile_edit(request, username, edit_profile_form=EditProfileForm,
 
     Edits a profile selected by the supplied username. First checks
     permissions if the user is allowed to edit this profile, if denied will
-    show a 404. When the profile is succesfully edited will redirect to
+    show a 404. When the profile is successfully edited will redirect to
     ``success_url``.
 
     :param username:
@@ -536,8 +541,8 @@ def profile_edit(request, username, edit_profile_form=EditProfileForm,
         ``userena/edit_profile_form.html``.
 
     :param success_url:
-        Named URL which be passed on to a django ``reverse`` function after the
-        form is successfully saved. Defaults to the ``userena_detail`` url.
+        Named URL which will be passed on to a django ``reverse`` function after
+        the form is successfully saved. Defaults to the ``userena_detail`` url.
 
     :param extra_context:
         Dictionary containing variables that are passed on to the
@@ -554,7 +559,7 @@ def profile_edit(request, username, edit_profile_form=EditProfileForm,
         Instance of the ``Profile`` that is edited.
 
     """
-    user = get_object_or_404(User,
+    user = get_object_or_404(get_user_model(),
                              username__iexact=username)
 
     profile = user.get_profile()
@@ -584,8 +589,7 @@ def profile_edit(request, username, edit_profile_form=EditProfileForm,
     extra_context['profile'] = profile
     return ExtraContextTemplateView.as_view(template_name=template_name,
                                             extra_context=extra_context)(request)
-def profile_detail(
-    request, username,
+def profile_detail(request, username,
     template_name=userena_settings.USERENA_PROFILE_DETAIL_TEMPLATE,
     extra_context=None, **kwargs):
     """
@@ -608,9 +612,15 @@ def profile_detail(
         Instance of the currently viewed ``Profile``.
 
     """
-    user = get_object_or_404(User,
+    user = get_object_or_404(get_user_model(),
                              username__iexact=username)
-    profile = user.get_profile()
+
+    profile_model = get_profile_model()
+    try:
+        profile = user.get_profile()
+    except profile_model.DoesNotExist:
+        profile = profile_model.objects.create(user=user)
+
     if not profile.can_view_profile(request.user):
         return HttpResponseForbidden(_("You don't have permission to view this profile."))
     if not extra_context: extra_context = dict()
@@ -675,11 +685,9 @@ def profile_list(request, page=1, template_name='userena/profile_list.html',
     queryset = profile_model.objects.get_visible_profiles(request.user)
 
     if not extra_context: extra_context = dict()
-    return list_detail.object_list(request,
-                                   queryset=queryset,
+    return ProfileListView.as_view(queryset=queryset,
                                    paginate_by=paginate_by,
                                    page=page,
                                    template_name=template_name,
                                    extra_context=extra_context,
-                                   template_object_name='profile',
-                                   **kwargs)
+                                   **kwargs)(request)
